.. AUTO-GENERATED FILE -- DO NOT EDIT!

Module: :mod:`feature`
======================
.. automodule:: skimage.feature

.. currentmodule:: skimage.feature
.. autosummary::

   skimage.feature.blob_dog
   skimage.feature.blob_doh
   skimage.feature.blob_log
   skimage.feature.canny
   skimage.feature.corner_fast
   skimage.feature.corner_foerstner
   skimage.feature.corner_harris
   skimage.feature.corner_kitchen_rosenfeld
   skimage.feature.corner_moravec
   skimage.feature.corner_orientations
   skimage.feature.corner_peaks
   skimage.feature.corner_shi_tomasi
   skimage.feature.corner_subpix
   skimage.feature.daisy
   skimage.feature.draw_haar_like_feature
   skimage.feature.draw_multiblock_lbp
   skimage.feature.greycomatrix
   skimage.feature.greycoprops
   skimage.feature.haar_like_feature
   skimage.feature.haar_like_feature_coord
   skimage.feature.hessian_matrix
   skimage.feature.hessian_matrix_det
   skimage.feature.hessian_matrix_eigvals
   skimage.feature.hog
   skimage.feature.local_binary_pattern
   skimage.feature.masked_register_translation
   skimage.feature.match_descriptors
   skimage.feature.match_template
   skimage.feature.multiblock_lbp
   skimage.feature.peak_local_max
   skimage.feature.plot_matches
   skimage.feature.register_translation
   skimage.feature.shape_index
   skimage.feature.structure_tensor
   skimage.feature.structure_tensor_eigvals

   skimage.feature.BRIEF
   skimage.feature.CENSURE
   skimage.feature.Cascade
   skimage.feature.ORB


blob_dog
--------

.. autofunction:: skimage.feature.blob_dog


.. include:: skimage.feature.blob_dog.examples

blob_doh
--------

.. autofunction:: skimage.feature.blob_doh


.. include:: skimage.feature.blob_doh.examples

blob_log
--------

.. autofunction:: skimage.feature.blob_log


.. include:: skimage.feature.blob_log.examples

canny
-----

.. autofunction:: skimage.feature.canny


.. include:: skimage.feature.canny.examples

corner_fast
-----------

.. autofunction:: skimage.feature.corner_fast


.. include:: skimage.feature.corner_fast.examples

corner_foerstner
----------------

.. autofunction:: skimage.feature.corner_foerstner


.. include:: skimage.feature.corner_foerstner.examples

corner_harris
-------------

.. autofunction:: skimage.feature.corner_harris


.. include:: skimage.feature.corner_harris.examples

corner_kitchen_rosenfeld
------------------------

.. autofunction:: skimage.feature.corner_kitchen_rosenfeld


.. include:: skimage.feature.corner_kitchen_rosenfeld.examples

corner_moravec
--------------

.. autofunction:: skimage.feature.corner_moravec


.. include:: skimage.feature.corner_moravec.examples

corner_orientations
-------------------

.. autofunction:: skimage.feature.corner_orientations


.. include:: skimage.feature.corner_orientations.examples

corner_peaks
------------

.. autofunction:: skimage.feature.corner_peaks


.. include:: skimage.feature.corner_peaks.examples

corner_shi_tomasi
-----------------

.. autofunction:: skimage.feature.corner_shi_tomasi


.. include:: skimage.feature.corner_shi_tomasi.examples

corner_subpix
-------------

.. autofunction:: skimage.feature.corner_subpix


.. include:: skimage.feature.corner_subpix.examples

daisy
-----

.. autofunction:: skimage.feature.daisy


.. include:: skimage.feature.daisy.examples

draw_haar_like_feature
----------------------

.. autofunction:: skimage.feature.draw_haar_like_feature


.. include:: skimage.feature.draw_haar_like_feature.examples

draw_multiblock_lbp
-------------------

.. autofunction:: skimage.feature.draw_multiblock_lbp


.. include:: skimage.feature.draw_multiblock_lbp.examples

greycomatrix
------------

.. autofunction:: skimage.feature.greycomatrix


.. include:: skimage.feature.greycomatrix.examples

greycoprops
-----------

.. autofunction:: skimage.feature.greycoprops


.. include:: skimage.feature.greycoprops.examples

haar_like_feature
-----------------

.. autofunction:: skimage.feature.haar_like_feature


.. include:: skimage.feature.haar_like_feature.examples

haar_like_feature_coord
-----------------------

.. autofunction:: skimage.feature.haar_like_feature_coord


.. include:: skimage.feature.haar_like_feature_coord.examples

hessian_matrix
--------------

.. autofunction:: skimage.feature.hessian_matrix


.. include:: skimage.feature.hessian_matrix.examples

hessian_matrix_det
------------------

.. autofunction:: skimage.feature.hessian_matrix_det


.. include:: skimage.feature.hessian_matrix_det.examples

hessian_matrix_eigvals
----------------------

.. autofunction:: skimage.feature.hessian_matrix_eigvals


.. include:: skimage.feature.hessian_matrix_eigvals.examples

hog
---

.. autofunction:: skimage.feature.hog


.. include:: skimage.feature.hog.examples

local_binary_pattern
--------------------

.. autofunction:: skimage.feature.local_binary_pattern


.. include:: skimage.feature.local_binary_pattern.examples

masked_register_translation
---------------------------

.. autofunction:: skimage.feature.masked_register_translation


.. include:: skimage.feature.masked_register_translation.examples

match_descriptors
-----------------

.. autofunction:: skimage.feature.match_descriptors


.. include:: skimage.feature.match_descriptors.examples

match_template
--------------

.. autofunction:: skimage.feature.match_template


.. include:: skimage.feature.match_template.examples

multiblock_lbp
--------------

.. autofunction:: skimage.feature.multiblock_lbp


.. include:: skimage.feature.multiblock_lbp.examples

peak_local_max
--------------

.. autofunction:: skimage.feature.peak_local_max


.. include:: skimage.feature.peak_local_max.examples

plot_matches
------------

.. autofunction:: skimage.feature.plot_matches


.. include:: skimage.feature.plot_matches.examples

register_translation
--------------------

.. autofunction:: skimage.feature.register_translation


.. include:: skimage.feature.register_translation.examples

shape_index
-----------

.. autofunction:: skimage.feature.shape_index


.. include:: skimage.feature.shape_index.examples

structure_tensor
----------------

.. autofunction:: skimage.feature.structure_tensor


.. include:: skimage.feature.structure_tensor.examples

structure_tensor_eigvals
------------------------

.. autofunction:: skimage.feature.structure_tensor_eigvals


.. include:: skimage.feature.structure_tensor_eigvals.examples


:class:`BRIEF`
--------------


.. autoclass:: BRIEF
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.feature.BRIEF.examples


:class:`CENSURE`
----------------


.. autoclass:: CENSURE
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.feature.CENSURE.examples


:class:`Cascade`
----------------


.. autoclass:: Cascade
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.feature.Cascade.examples


:class:`ORB`
------------


.. autoclass:: ORB
  :members:
  :undoc-members:
  :show-inheritance:

  .. automethod:: __init__

.. include:: skimage.feature.ORB.examples

